<?php
/**
 * Cabins in the lower decks may use this class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class LowCabin extends BaseCabin implements TradeableItem, ConstructableShipPart {
	// Konstruktor
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set description
		$this->setObjectDescription("2Star-Class-Kabine");

		// Generate unique ID number
		$this->generateUniqueId();

		// Clean up a little
		$this->removeSystemArray();
	}

	// 2-Sterne-Klasse erstellen
	public final static function createLowCabin ($numLuxury, $numRooms, $numBeds, $dim) {
		// Get new instance
		$lowInstance = new LowCabin();

		// Debug message
		if ((defined('DEBUG_CABIN')) || (defined('DEBUG_ALL'))) $lowInstance->getDebugInstance()->output(sprintf("[%s:%d] Eine 2-Sterne-Kabine wird konstruiert...<br />\n",
			__CLASS__,
			__LINE__
		));

		// Abmasse extrahieren
		$lowInstance->extractDimensions($dim);

		// Den Rest auch setzen
		$lowInstance->setNumCabin($numLuxury);
		$lowInstance->setNumRooms($numRooms);
		$lowInstance->setNumBeds($numBeds);

		// Nicht noetig!
		$lowInstance->removePartInstance();

		// Instanz zurueckgeben
		return $lowInstance;
	}

	// Overwritten method for tradeable items
	public function isTradeable () {
		return true;
	}

	/**
	 * Limits this object with an ObjectLimits instance
	 */
	public function limitObject (ObjectLimits $limitInstance) {
		ApplicationEntryPoint::app_die("".__METHOD__." reached! Stub!");
	}
}

// [EOF]
?>
